@@ -5,9 +5,6 @@ from .functions import (
     remove_outliers,
     drop_duplicates,
     change_data_type,
-)
-from .functions import round_data, filter_dataframe, truncate_dataframe, sort_values, transpose
-from .functions import (
     min_max_scale,
     max_abs_scale,
     robust_scale,
@@ -17,5 +14,19 @@ from .functions import (
     one_hot_encode,
     remove_mismatch_data,
     clean_data,
+    round_data, 
+    filter_dataframe, 
+    truncate_dataframe, 
+    sort_values, 
+    transpose,
+    rename_columns,
+    select_columns,
+    clean_column_names,
+    clip,
+    merge,
+    clean_data,
+    split_data,        
 )
-from .templating import *
+
+
+from .handler import *
